climind.stats package
=====================

Submodules
----------

climind.stats.paragraphs module
-------------------------------

.. automodule:: climind.stats.paragraphs
   :members:
   :undoc-members:
   :show-inheritance:

climind.stats.utils module
--------------------------

.. automodule:: climind.stats.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: climind.stats
   :members:
   :undoc-members:
   :show-inheritance:
